/*
 * Copyright 2012 Shared Learning Collaborative, LLC
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.slc.sli.dashboard.manager.impl;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import junit.framework.Assert;

import org.junit.Before;
import org.junit.Test;

import org.slc.sli.dashboard.client.APIClient;
import org.slc.sli.dashboard.client.SDKAPIClient;
import org.slc.sli.dashboard.entity.Config;
import org.slc.sli.dashboard.entity.ConfigMap;
import org.slc.sli.dashboard.entity.EdOrgKey;
import org.slc.sli.dashboard.entity.GenericEntity;
import org.slc.sli.dashboard.util.JsonConverter;

/**
 *
 * TODO: add class level javadoc
 *
 */
public class ConfigManagerImplTest {
    private APIClient apiClient = null;
    private ConfigManagerImpl configManager = null;

    @Before
    public void setUp() throws Exception {
        this.apiClient = new SDKAPIClient() {
            @Override
            public GenericEntity getEducationalOrganization(String token, String id) {
                GenericEntity entity = null;
                if (id.equals("2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82")) {
                    entity = JsonConverter
                            .fromJson(
                                    "{\"id\":\"2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\",\"accountabilityRatings\":[],\"organizationCategories\":[\"Local Education Agency\"],\"address\":[{\"postalCode\":\"00000\",\"streetNumberName\":\"123 Street\",\"stateAbbreviation\":\"IL\",\"city\":\"Chicago\"}],\"educationOrgIdentificationCode\":[],\"stateOrganizationId\":\"IL-DAYBREAK\",\"programReference\":[],\"parentEducationAgencyReference\":\"2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\",\"links\":[{\"linkName\":\"self\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"custom\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82/custom\"},{\"linkName\":\"getParentEducationOrganization\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getFeederSchools\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/schools?parentEducationAgencyReference\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getStaffEducationOrgAssignmentAssociations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations\"},{\"linkName\":\"getStaff\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations/staff\"},{\"linkName\":\"getCourses\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/courses?schoolId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getFeederEducationOrganizations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations?parentEducationAgencyReference\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSections\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sections?schoolId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getAttendances\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/attendances?schoolId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getCohorts\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/cohorts?educationOrgId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSessions\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sessions?schoolId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getDisciplineIncidents\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/disciplineIncidents?schoolId\u003d2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82\"}],\"telephone\":[],\"nameOfInstitution\":\"Daybreak School District 4529\"}",
                                    GenericEntity.class);
                } else if (id.equals("2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82")) {
                    entity = JsonConverter
                            .fromJson(
                                    "{\"id\":\"2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\",\"accountabilityRatings\":[],\"organizationCategories\":[\"State Education Agency\"],\"address\":[{\"postalCode\":\"00000\",\"streetNumberName\":\"123 Street\",\"stateAbbreviation\":\"IL\",\"city\":\"Chicago\"}],\"educationOrgIdentificationCode\":[],\"stateOrganizationId\":\"IL\",\"programReference\":[],\"links\":[{\"linkName\":\"self\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"custom\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/custom\"},{\"linkName\":\"getFeederSchools\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/schools?parentEducationAgencyReference\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getStaffEducationOrgAssignmentAssociations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations\"},{\"linkName\":\"getStaff\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations/staff\"},{\"linkName\":\"getCourses\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/courses?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getFeederEducationOrganizations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations?parentEducationAgencyReference\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSections\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sections?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getAttendances\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/attendances?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getCohorts\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/cohorts?educationOrgId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSessions\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sessions?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getDisciplineIncidents\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/disciplineIncidents?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"}],\"telephone\":[],\"nameOfInstitution\":\"Illinois State Board of Education\"}",
                                    GenericEntity.class);
                }
                return entity;
            }

            @Override
            public GenericEntity getParentEducationalOrganization(String token, GenericEntity educationalOrganization) {
                GenericEntity entity = null;
                if (educationalOrganization.getId().equals("2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82")) {
                    entity = JsonConverter
                            .fromJson(
                                    "{\"id\":\"2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\",\"accountabilityRatings\":[],\"organizationCategories\":[\"State Education Agency\"],\"address\":[{\"postalCode\":\"00000\",\"streetNumberName\":\"123 Street\",\"stateAbbreviation\":\"IL\",\"city\":\"Chicago\"}],\"educationOrgIdentificationCode\":[],\"stateOrganizationId\":\"IL\",\"programReference\":[],\"links\":[{\"linkName\":\"self\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"custom\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/custom\"},{\"linkName\":\"getFeederSchools\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/schools?parentEducationAgencyReference\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getStaffEducationOrgAssignmentAssociations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations\"},{\"linkName\":\"getStaff\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations/2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82/staffEducationOrgAssignmentAssociations/staff\"},{\"linkName\":\"getCourses\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/courses?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getFeederEducationOrganizations\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/educationOrganizations?parentEducationAgencyReference\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSections\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sections?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getAttendances\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/attendances?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getCohorts\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/cohorts?educationOrgId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getSessions\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/sessions?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"},{\"linkName\":\"getDisciplineIncidents\",\"resource\":\"http://local.slidev.org:8080/api/rest/v1/disciplineIncidents?schoolId\u003d2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82\"}],\"telephone\":[],\"nameOfInstitution\":\"Illinois State Board of Education\"}",
                                    GenericEntity.class);
                }
                return entity;
            }

            @Override
            public ConfigMap getEdOrgCustomData(String token, String id) {
                ConfigMap configMap = null;
                if (id.equals("2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82")) {
                    configMap = JsonConverter
                            .fromJson(
                                    "{\"config\":{\"listOfStudents\":{\"id\":\"listOfStudents\",\"type\":\"PANEL\",\"data\":{\"entity\":\"listOfStudents\",\"cacheKey\":\"listOfStudents\",\"params\":{\"assessmentFilter\":{\"StateTest Reading\":\"HIGHEST_EVER\",\"StateTest Writing\":\"MOST_RECENT_WINDOW\",\"READ 2.0\":\"MOST_RECENT_WINDOW\",\"TRC\":\"MOST_RECENT_WINDOW\",\"SAT Reading\":\"HIGHEST_EVER\",\"SAT Writing\":\"HIGHEST_EVER\",\"AP Language\":\"HIGHEST_EVER\",\"AP Literature\":\"HIGHEST_EVER\"}},\"lazy\":true},\"items\":[{\"name\":\"Middle School ELA View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Third grade\",\"Fourth grade\",\"Fifth grade\",\"Sixth grade\",\"Seventh grade\",\"Eighth grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"StateTest Reading (highest ever)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.StateTest Reading.perfLevel\",\"width\":\"150\",\"formatter\":\"FuelGaugeWithScore\",\"sorter\":\"ProxyInt\",\"params\":{\"sortField\":\"assessments.StateTest Reading.Scale score\",\"name\":\"StateTest Reading\",\"valueField\":\"Scale score\",\"fieldName\":\"StateTestReading\",\"cutPoints\":{\"5\":{\"style\":\"color-widget-darkgreen\"},\"4\":{\"style\":\"color-widget-green\"},\"3\":{\"style\":\"color-widget-yellow\"},\"2\":{\"style\":\"color-widget-orange\"},\"1\":{\"style\":\"color-widget-red\"}}},\"name\":\"Performance Level\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Reading.Scale score\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"SS\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Reading.Other\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"Lexile\",\"type\":\"FIELD\"}]},{\"name\":\"StateTest Writing (most recent)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.StateTest Writing.perfLevel\",\"width\":\"150\",\"formatter\":\"FuelGaugeWithScore\",\"sorter\":\"ProxyInt\",\"params\":{\"sortField\":\"assessments.StateTest Writing.Scale score\",\"name\":\"StateTest Writing\",\"valueField\":\"Scale score\",\"fieldName\":\"StateTestWriting\",\"cutPoints\":{\"5\":{\"style\":\"color-widget-darkgreen\"},\"4\":{\"style\":\"color-widget-green\"},\"3\":{\"style\":\"color-widget-yellow\"},\"2\":{\"style\":\"color-widget-orange\"},\"1\":{\"style\":\"color-widget-red\"}}},\"name\":\"Performance Level\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Writing.Scale score\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"SS\",\"type\":\"FIELD\"}]},{\"name\":\"Current Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"currentSession-0\",\"width\":\"100\",\"formatter\":\"Grade\",\"sorter\":\"LettersAndNumbers\",\"name\":\"Unit Test 1\",\"type\":\"FIELD\"}]},{\"name\":\"Final Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"previousSemester\",\"width\":\"100\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"Last Semester\",\"type\":\"FIELD\"},{\"field\":\"twoSemestersAgo\",\"width\":\"90\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"2 Semesters ago\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance (current school year)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.attendanceRate\",\"width\":\"75\",\"formatter\":\"CutPoint\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"89\":{\"style\":\"color-widget-red\"},\"94\":{\"style\":\"color-widget-yellow\"},\"98\":{\"style\":\"color-widget-green\"},\"100\":{\"style\":\"color-widget-darkgreen\"}}},\"name\":\"Attendance Rate %\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyRate\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Rate %\",\"type\":\"FIELD\"}]}]},{\"name\":\"Early Literacy View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Kindergarten\",\"First grade\",\"Second grade\",\"Third grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"READ 2.0\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.READ 2_0.perfLevel\",\"width\":\"100\",\"name\":\"Performance Level\",\"type\":\"FIELD\"}]},{\"name\":\"Reading\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.TRC.readingLevel\",\"width\":\"100\",\"name\":\"RL\",\"type\":\"FIELD\"},{\"field\":\"assessments.TRC.profLevel\",\"width\":\"100\",\"name\":\"Prof. Level\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"}]}]},{\"name\":\"College Ready ELA View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"Reading Test Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.SAT Reading.x\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"SAT\",\"type\":\"FIELD\"},{\"field\":\"assessments.SAT Reading.percentile\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"%ile\",\"type\":\"FIELD\"}]},{\"name\":\"Writing Test Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.SAT Writing.x\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"SAT\",\"type\":\"FIELD\"},{\"field\":\"assessments.SAT Writing.percentile\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"%ile\",\"type\":\"FIELD\"}]},{\"name\":\"AP Eng. Exam Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.AP Language.x\",\"width\":\"100\",\"name\":\"Lang.\",\"type\":\"FIELD\"},{\"field\":\"assessments.AP Literature.x\",\"width\":\"100\",\"name\":\"Lit.\",\"type\":\"FIELD\"}]},{\"name\":\"Final Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"previousSemester\",\"width\":\"100\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"Last Semester\",\"type\":\"FIELD\"},{\"field\":\"twoSemestersAgo\",\"width\":\"90\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"2 Semesters ago\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.attendanceRate\",\"width\":\"75\",\"formatter\":\"CutPoint\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"89\":{\"style\":\"color-widget-red\"},\"94\":{\"style\":\"color-widget-yellow\"},\"98\":{\"style\":\"color-widget-green\"},\"100\":{\"style\":\"color-widget-darkgreen\"}}},\"name\":\"Attendance Rate %\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyRate\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Rate %\",\"type\":\"FIELD\"}]}]}],\"root\":\"students\"},\"student\":{\"id\":\"student\",\"name\":\"SLC - Student Profile\",\"type\":\"LAYOUT\",\"data\":{\"entity\":\"student\",\"cacheKey\":\"student\",\"lazy\":false},\"items\":[{\"id\":\"csi\",\"name\":\"Student Info\",\"type\":\"PANEL\"},{\"id\":\"tab7\",\"name\":\"Elementary School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Infant/toddler\",\"Early Education\",\"Preschool/Prekindergarten\",\"Transitional Kindergarten\",\"Kindergarten\",\"First Grade\",\"Second Grade\",\"Third Grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab8\",\"name\":\"Middle School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Fourth Grade\",\"Fifth Grade\",\"Sixth Grade\",\"Seventh Grade\",\"Eighth grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab9\",\"name\":\"High School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\",\"Adult Education\",\"Grade 13\",\"Postsecondary\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab2\",\"name\":\"Attendance and Discipline\",\"type\":\"TAB\",\"items\":[{\"id\":\"attendanceHist\",\"type\":\"REPEAT_HEADER_GRID\"},{\"id\":\"studentAttendanceCalendar\",\"type\":\"PANEL\"}]},{\"id\":\"tabE\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Infant/toddler\",\"Early Education\",\"Preschool/Prekindergarten\",\"Transitional Kindergarten\",\"Kindergarten\",\"First Grade\",\"Second Grade\",\"Third Grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistREAD2\",\"type\":\"GRID\"}]},{\"id\":\"tabM\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Fourth Grade\",\"Fifth Grade\",\"Sixth Grade\",\"Seventh Grade\",\"Eighth grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistStateTestR\",\"type\":\"GRID\"},{\"id\":\"assessmentHistStateTestW\",\"type\":\"GRID\"}]},{\"id\":\"tabH\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\",\"Adult Education\",\"Grade 13\",\"Postsecondary\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistAPE\",\"type\":\"GRID\"},{\"id\":\"assessmentHistSATR\",\"type\":\"GRID\"},{\"id\":\"assessmentHistSATW\",\"type\":\"GRID\"}]},{\"id\":\"tab4\",\"name\":\"Grades and Credits\",\"type\":\"TAB\",\"items\":[{\"id\":\"transcriptHistory\",\"type\":\"PANEL\"}]}]},\"assessmentHistAPE\":{\"id\":\"assessmentHistAPE\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : AP English\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistAPE\",\"params\":{\"assessmentFamily\":\"AP.AP Eng\"},\"lazy\":false}},\"assessmentHistREAD2\":{\"id\":\"assessmentHistREAD2\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : READ 2.0\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistREAD2\",\"params\":{\"assessmentFamily\":\"READ 2.0.READ 2.0 Grade 1\"},\"lazy\":false}},\"assessmentHistStateTestR\":{\"id\":\"assessmentHistStateTestR\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : StateTest Reading\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistStateTestR\",\"params\":{\"assessmentFamily\":\"StateTest Reading\"},\"lazy\":false}},\"assessmentHistStateTestW\":{\"id\":\"assessmentHistStateTestW\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : StateTest Writing\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistStateTestW\",\"params\":{\"assessmentFamily\":\"StateTest Writing\"},\"lazy\":false}},\"assessmentHistSATR\":{\"id\":\"assessmentHistSATR\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : SAT Reading\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistSATR\",\"params\":{\"assessmentFamily\":\"SAT Reading\"},\"lazy\":false}},\"assessmentHistSATW\":{\"id\":\"assessmentHistSATW\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : SAT Writing\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistSATW\",\"params\":{\"assessmentFamily\":\"SAT Writing\"},\"lazy\":false}}}}",
                                    ConfigMap.class);
                } else if (id.equals("2012cu-dd9c379e-e7cd-11e1-a937-68a86d3c2f82")) {
                    configMap = JsonConverter
                            .fromJson(
                                    "{\"config\":{\"listOfStudents\":{\"id\":\"listOfStudents\",\"type\":\"PANEL\",\"data\":{\"entity\":\"listOfStudents\",\"cacheKey\":\"listOfStudents\",\"params\":{\"assessmentFilter\":{\"StateTest Reading\":\"HIGHEST_EVER\",\"StateTest Writing\":\"MOST_RECENT_WINDOW\",\"READ 2.0\":\"MOST_RECENT_WINDOW\",\"TRC\":\"MOST_RECENT_WINDOW\",\"SAT Reading\":\"HIGHEST_EVER\",\"SAT Writing\":\"HIGHEST_EVER\",\"AP Language\":\"HIGHEST_EVER\",\"AP Literature\":\"HIGHEST_EVER\"}},\"lazy\":true},\"items\":[{\"name\":\"Middle School ELA View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Third grade\",\"Fourth grade\",\"Fifth grade\",\"Sixth grade\",\"Seventh grade\",\"Eighth grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"StateTest Reading (highest ever)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.StateTest Reading.perfLevel\",\"width\":\"150\",\"formatter\":\"FuelGaugeWithScore\",\"sorter\":\"ProxyInt\",\"params\":{\"sortField\":\"assessments.StateTest Reading.Scale score\",\"name\":\"StateTest Reading\",\"valueField\":\"Scale score\",\"fieldName\":\"StateTestReading\",\"cutPoints\":{\"5\":{\"style\":\"color-widget-darkgreen\"},\"4\":{\"style\":\"color-widget-green\"},\"3\":{\"style\":\"color-widget-yellow\"},\"2\":{\"style\":\"color-widget-orange\"},\"1\":{\"style\":\"color-widget-red\"}}},\"name\":\"Performance Level\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Reading.Scale score\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"SS\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Reading.Other\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"Lexile\",\"type\":\"FIELD\"}]},{\"name\":\"StateTest Writing (most recent)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.StateTest Writing.perfLevel\",\"width\":\"150\",\"formatter\":\"FuelGaugeWithScore\",\"sorter\":\"ProxyInt\",\"params\":{\"sortField\":\"assessments.StateTest Writing.Scale score\",\"name\":\"StateTest Writing\",\"valueField\":\"Scale score\",\"fieldName\":\"StateTestWriting\",\"cutPoints\":{\"5\":{\"style\":\"color-widget-darkgreen\"},\"4\":{\"style\":\"color-widget-green\"},\"3\":{\"style\":\"color-widget-yellow\"},\"2\":{\"style\":\"color-widget-orange\"},\"1\":{\"style\":\"color-widget-red\"}}},\"name\":\"Performance Level\",\"type\":\"FIELD\"},{\"field\":\"assessments.StateTest Writing.Scale score\",\"width\":\"45\",\"sorter\":\"int\",\"name\":\"SS\",\"type\":\"FIELD\"}]},{\"name\":\"Current Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"currentSession-0\",\"width\":\"100\",\"formatter\":\"Grade\",\"sorter\":\"LettersAndNumbers\",\"name\":\"Unit Test 1\",\"type\":\"FIELD\"}]},{\"name\":\"Final Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"previousSemester\",\"width\":\"100\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"Last Semester\",\"type\":\"FIELD\"},{\"field\":\"twoSemestersAgo\",\"width\":\"90\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"2 Semesters ago\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance (current school year)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.attendanceRate\",\"width\":\"75\",\"formatter\":\"CutPoint\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"89\":{\"style\":\"color-widget-red\"},\"94\":{\"style\":\"color-widget-yellow\"},\"98\":{\"style\":\"color-widget-green\"},\"100\":{\"style\":\"color-widget-darkgreen\"}}},\"name\":\"Attendance Rate %\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyRate\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Rate %\",\"type\":\"FIELD\"}]}]},{\"name\":\"Early Literacy View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Kindergarten\",\"First grade\",\"Second grade\",\"Third grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"READ 2.0\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.READ 2_0.perfLevel\",\"width\":\"100\",\"name\":\"Performance Level\",\"type\":\"FIELD\"}]},{\"name\":\"Reading\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.TRC.readingLevel\",\"width\":\"100\",\"name\":\"RL\",\"type\":\"FIELD\"},{\"field\":\"assessments.TRC.profLevel\",\"width\":\"100\",\"name\":\"Prof. Level\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"}]}]},{\"name\":\"College Ready ELA View\",\"type\":\"FIELD\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\"]},\"items\":[{\"field\":\"name.fullName\",\"width\":\"150\",\"style\":\"ui-ellipsis\",\"formatter\":\"restLink\",\"params\":{\"link\":\"student\",\"target\":\"_self\"},\"name\":\"Student\",\"type\":\"FIELD\"},{\"field\":\"programParticipation\",\"width\":\"60\",\"formatter\":\"Lozenge\",\"name\":\"\",\"type\":\"FIELD\"},{\"name\":\"Reading Test Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.SAT Reading.x\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"SAT\",\"type\":\"FIELD\"},{\"field\":\"assessments.SAT Reading.percentile\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"%ile\",\"type\":\"FIELD\"}]},{\"name\":\"Writing Test Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.SAT Writing.x\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"SAT\",\"type\":\"FIELD\"},{\"field\":\"assessments.SAT Writing.percentile\",\"width\":\"100\",\"sorter\":\"int\",\"name\":\"%ile\",\"type\":\"FIELD\"}]},{\"name\":\"AP Eng. Exam Scores (Highest)\",\"type\":\"FIELD\",\"items\":[{\"field\":\"assessments.AP Language.x\",\"width\":\"100\",\"name\":\"Lang.\",\"type\":\"FIELD\"},{\"field\":\"assessments.AP Literature.x\",\"width\":\"100\",\"name\":\"Lit.\",\"type\":\"FIELD\"}]},{\"name\":\"Final Grades\",\"type\":\"FIELD\",\"items\":[{\"field\":\"previousSemester\",\"width\":\"100\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"Last Semester\",\"type\":\"FIELD\"},{\"field\":\"twoSemestersAgo\",\"width\":\"90\",\"formatter\":\"TearDrop\",\"sorter\":\"LetterGrade\",\"name\":\"2 Semesters ago\",\"type\":\"FIELD\"}]},{\"name\":\"Attendance\",\"type\":\"FIELD\",\"items\":[{\"field\":\"attendances.absenceCount\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Absence Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.attendanceRate\",\"width\":\"75\",\"formatter\":\"CutPoint\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"89\":{\"style\":\"color-widget-red\"},\"94\":{\"style\":\"color-widget-yellow\"},\"98\":{\"style\":\"color-widget-green\"},\"100\":{\"style\":\"color-widget-darkgreen\"}}},\"name\":\"Attendance Rate %\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyCount\",\"width\":\"50\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Count\",\"type\":\"FIELD\"},{\"field\":\"attendances.tardyRate\",\"width\":\"60\",\"formatter\":\"CutPointReverse\",\"sorter\":\"int\",\"params\":{\"cutPoints\":{\"0\":{\"style\":\"color-widget-darkgreen\"},\"1\":{\"style\":\"color-widget-green\"},\"6\":{\"style\":\"color-widget-yellow\"},\"11\":{\"style\":\"color-widget-red\"}}},\"name\":\"Tardy Rate %\",\"type\":\"FIELD\"}]}]}],\"root\":\"students\"},\"student\":{\"id\":\"student\",\"name\":\"SLC - Student Profile\",\"type\":\"LAYOUT\",\"data\":{\"entity\":\"student\",\"cacheKey\":\"student\",\"lazy\":false},\"items\":[{\"id\":\"csi\",\"name\":\"Student Info\",\"type\":\"PANEL\"},{\"id\":\"tab7\",\"name\":\"Elementary School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Infant/toddler\",\"Early Education\",\"Preschool/Prekindergarten\",\"Transitional Kindergarten\",\"Kindergarten\",\"First Grade\",\"Second Grade\",\"Third Grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab8\",\"name\":\"Middle School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Fourth Grade\",\"Fifth Grade\",\"Sixth Grade\",\"Seventh Grade\",\"Eighth grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab9\",\"name\":\"High School Overview\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\",\"Adult Education\",\"Grade 13\",\"Postsecondary\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"contactInfo\",\"type\":\"PANEL\"},{\"id\":\"enrollmentHist\",\"name\":\"Student Enrollment Panel\",\"type\":\"GRID\"}]},{\"id\":\"tab2\",\"name\":\"Attendance and Discipline\",\"type\":\"TAB\",\"items\":[{\"id\":\"attendanceHist\",\"type\":\"REPEAT_HEADER_GRID\"},{\"id\":\"studentAttendanceCalendar\",\"type\":\"PANEL\"}]},{\"id\":\"tabE\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Infant/toddler\",\"Early Education\",\"Preschool/Prekindergarten\",\"Transitional Kindergarten\",\"Kindergarten\",\"First Grade\",\"Second Grade\",\"Third Grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistREAD2\",\"type\":\"GRID\"}]},{\"id\":\"tabM\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Fourth Grade\",\"Fifth Grade\",\"Sixth Grade\",\"Seventh Grade\",\"Eighth grade\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistStateTestR\",\"type\":\"GRID\"},{\"id\":\"assessmentHistStateTestW\",\"type\":\"GRID\"}]},{\"id\":\"tabH\",\"name\":\"Assessments\",\"type\":\"TAB\",\"condition\":{\"field\":\"gradeLevel\",\"value\":[\"Ninth grade\",\"Tenth grade\",\"Eleventh grade\",\"Twelfth grade\",\"Adult Education\",\"Grade 13\",\"Postsecondary\",\"Other\",\"Ungraded\",\"Not Available\"]},\"items\":[{\"id\":\"assessmentHistAPE\",\"type\":\"GRID\"},{\"id\":\"assessmentHistSATR\",\"type\":\"GRID\"},{\"id\":\"assessmentHistSATW\",\"type\":\"GRID\"}]},{\"id\":\"tab4\",\"name\":\"Grades and Credits\",\"type\":\"TAB\",\"items\":[{\"id\":\"transcriptHistory\",\"type\":\"PANEL\"}]}]},\"assessmentHistAPE\":{\"id\":\"assessmentHistAPE\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : AP English\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistAPE\",\"params\":{\"assessmentFamily\":\"AP.AP Eng\"},\"lazy\":false}},\"assessmentHistREAD2\":{\"id\":\"assessmentHistREAD2\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : READ 2.0\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistREAD2\",\"params\":{\"assessmentFamily\":\"READ 2.0.READ 2.0 Grade 1\"},\"lazy\":false}},\"assessmentHistStateTestR\":{\"id\":\"assessmentHistStateTestR\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : StateTest Reading\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistStateTestR\",\"params\":{\"assessmentFamily\":\"StateTest Reading\"},\"lazy\":false}},\"assessmentHistStateTestW\":{\"id\":\"assessmentHistStateTestW\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : StateTest Writing\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistStateTestW\",\"params\":{\"assessmentFamily\":\"StateTest Writing\"},\"lazy\":false}},\"assessmentHistSATR\":{\"id\":\"assessmentHistSATR\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : SAT Reading\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistSATR\",\"params\":{\"assessmentFamily\":\"SAT Reading\"},\"lazy\":false}},\"assessmentHistSATW\":{\"id\":\"assessmentHistSATW\",\"parentId\":\"assessmentHist\",\"name\":\"Test History : SAT Writing\",\"type\":\"GRID\",\"data\":{\"cacheKey\":\"assessmentHistSATW\",\"params\":{\"assessmentFamily\":\"SAT Writing\"},\"lazy\":false}}}}",
                                    ConfigMap.class);
                }
                return configMap;
            }
        };
    }

    @Test
    public void testGetAllConfigByType() {
        configManager = new ConfigManagerImpl();
        configManager.setApiClient(apiClient);
        configManager.setDriverConfigLocation("config");
        configManager.setUserConfigLocation("custom");

        Map<String, String> params = new HashMap<String, String>();
        params.put("type", "PANEL");
        String edOrgId = "2012de-df94acd2-e7cd-11e1-a937-68a86d3c2f82";
        Map<String, Collection<Config>> mapConfigs = configManager.getAllConfigByType("token", new EdOrgKey(edOrgId),
                params);

        Assert.assertEquals(3, mapConfigs.size());
        Collection<Config> defaultConfig = mapConfigs.get("default");
        Assert.assertNotNull(defaultConfig);
        Assert.assertEquals(10, defaultConfig.size());

        Collection<Config> sea = mapConfigs.get("State Education Agency");
        Assert.assertNotNull(sea);
        Assert.assertEquals(1, sea.size());

        Collection<Config> lea = mapConfigs.get("Local Education Agency");
        Assert.assertNotNull(lea);
        Assert.assertEquals(1, lea.size());
    }

}
